@@ -1,17 +1,19 @@
-import datetime
+import datetime as dt
 import itertools
+import json
 import logging
 import os
 
 import numpy as np
 import pandas as pd
+import requests
 from iexfinance.stocks import get_historical_intraday
 
 R = '#ff0000'
 G = '#55ff00'
 B = '#0015ff'
 C = 'cyan'
-INPUTS = 60
+INPUTS = 100
 BUY = 1
 SELL = 0
 EXIT = 2
@@ -22,8 +24,10 @@ os.environ['IEX_API_VERSION'] = 'iexcloud-sandbox'
 os.environ['IEX_TOKEN'] = TOKEN
 __author__ = 'Vlad Kochetov'
 __credits__ = ["Hemerson Tacon -- Stack overflow",
-               "hpaulj -- Stack overflow"]
-__version__ = "2.1.9"
+               "hpaulj -- Stack overflow",
+               "Войтенко Николай Поликарпович (Vojtenko Nikolaj Polikarpovich) -- helped me test the system of "
+               "interaction with the binance crypto exchange with 50 dollars."]
+__version__ = "3.0"
 
 TICKER = '^DJI'
 SCATTER_SIZE = 12
@@ -38,7 +42,7 @@ DEPO_COLOR_UP = 'green'
 DEPO_COLOR_DOWN = 'red'
 logger = logging.getLogger()
 logger.setLevel(50)
-logging.basicConfig(level=10, filename='trading.log')
+logging.basicConfig(level=20, filename='trading.log')
 
 
 def set_(data):
@@ -76,8 +80,8 @@ def inverse_4_col_df(df, columns):
 
 def get_data(ticker, undo_days):
     tuples = []
-    end = datetime.datetime.today()
-    date_list = [end - datetime.timedelta(days=d) for d in range(undo_days)]
+    end = dt.datetime.today()
+    date_list = [end - dt.timedelta(days=d) for d in range(undo_days)]
     for i in range(len(date_list)):
         ret = str(np.array(date_list[::-1])[i])[:10]
         ret = ret.split('-')
@@ -87,7 +91,7 @@ def get_data(ticker, undo_days):
 
     dataframes = []
     for date_ in tuples:
-        dat = datetime.datetime(*date_)
+        dat = dt.datetime(*date_)
         df_ = get_historical_intraday(ticker, date=dat, output_format='pandas')
         dataframes.append(df_)
     returns = pd.concat(dataframes, axis=0)
@@ -113,23 +117,12 @@ def anti_set_(seted):
     return ret
 
 
-def move_stop_to_breakeven(stop, open_, sig, price, diff, *args, **kwargs):
-    if sig == BUY and price > open_ and diff > 0:
-        stop_loss = (price * 2 + open_) / 3
-    elif sig == SELL and price < open_ and diff < 0:
-        stop_loss = (price * 2 + open_) / 3
-    else:
-        stop_loss = stop
-    return stop_loss
-
-
 def digit(data):
-    data = list(data)
     ret = []
-    for i in list(data):
-        if i == 0:
+    for element in list(data):
+        if element == 0:
             ret.append(EXIT)
-        elif i > 0:
+        elif element > 0:
             ret.append(BUY)
         else:
             ret.append(SELL)
@@ -145,3 +138,18 @@ def get_window(values, window):
 
 def nothing(ret):
     return ret
+
+
+def get_binance_data(ticker="BNBBTC", interval="1m", date_index=False):
+    url = f"https://api.binance.com/api/v1/klines?symbol={ticker}&interval={interval}"
+    data = json.loads(requests.get(url).text)
+    df = pd.DataFrame(data)
+    df.columns = ["open_time",
+                  "Open", "High", "Low", 'Close', 'Volume',
+                  'close_time', 'qav', 'num_trades',
+                  'taker_base_vol', 'taker_quote_vol', 'ignore']
+    for column in ["Open", "High", "Low", 'Close', 'Volume']:
+        df[column] = df[column].astype(float)
+    if date_index:
+        df.index = [dt.datetime.fromtimestamp(i / 1000) for i in df.close_time]
+    return df
